@@ -1,15 +1,33 @@
-"""
-parsedatetime
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+#
+# vim: sw=2 ts=2 sts=2
+#
+# Copyright 2004-2014 Mike Taylor
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+"""parsedatetime
 
 Parse human-readable date/time text.
 
 Requires Python 2.6 or later
 """
 
-__author__       = 'Mike Taylor (bear@code-bear.com)'
+__author__       = 'Mike Taylor (bear@bear.im)'
 __copyright__    = 'Copyright (c) 2004 Mike Taylor'
 __license__      = 'Apache v2.0'
-__version__      = '1.3'
+__version__      = '1.4'
 __contributors__ = [ 'Darshana Chhajed',
                      'Michael Lim (lim.ck.michael@gmail.com)',
                      'Bernd Zeimetz (bzed@debian.org)',
@@ -1984,11 +2002,11 @@ def _initSymbols(ptc):
 
         if len(am) > 0:
             ptc.am.append(am[0])
-            ptc.am.append('{}.{}.'.format(am[0], am[1]))
+            ptc.am.append('{0}.{1}.'.format(am[0], am[1]))
             am = am.lower()
             ptc.am.append(am)
             ptc.am.append(am[0])
-            ptc.am.append('{}.{}.'.format(am[0], am[1]))
+            ptc.am.append('{0}.{1}.'.format(am[0], am[1]))
     else:
         am     = ''
         ptc.am = [ '', '' ]
@@ -1999,11 +2017,11 @@ def _initSymbols(ptc):
 
         if len(pm) > 0:
             ptc.pm.append(pm[0])
-            ptc.pm.append('{}.{}.'.format(pm[0], pm[1]))
+            ptc.pm.append('{0}.{1}.'.format(pm[0], pm[1]))
             pm = pm.lower()
             ptc.pm.append(pm)
             ptc.pm.append(pm[0])
-            ptc.pm.append('{}.{}.'.format(pm[0], pm[1]))
+            ptc.pm.append('{0}.{1}.'.format(pm[0], pm[1]))
     else:
         pm     = ''
         ptc.pm = [ '', '' ]
