@@ -1,20 +1,10 @@
-
+# -*- coding: utf-8 -*-
 """
 pdt_locales
 
 All of the included locale classes shipped with pdt.
 """
 
-__author__       = 'Mike Taylor (bear@code-bear.com)'
-__copyright__    = 'Copyright (c) 2004 Mike Taylor'
-__license__      = 'Apache v2.0'
-__version__      = '1.0.0'
-__contributors__ = [ 'Darshana Chhajed',
-                     'Michael Lim (lim.ck.michael@gmail.com)',
-                     'Bernd Zeimetz (bzed@debian.org)',
-                   ]
-
-
 import datetime
 
 try:
@@ -261,7 +251,6 @@ class pdtLocale_icu(pdtLocale_base):
             self.dp_order = dp_order
 
 
-
 class pdtLocale_en(pdtLocale_base):
     """
     en_US Locale
@@ -293,6 +282,7 @@ class pdtLocale_au(pdtLocale_base):
 
         self.dp_order = [ 'd', 'm', 'y' ]
 
+
 class pdtLocale_es(pdtLocale_base):
     """
     es Locale
@@ -386,7 +376,7 @@ class pdtLocale_de(pdtLocale_base):
         self.units['days']    = [ 'tag',  'tage',     't' ]
         self.units['weeks']   = [ 'wochen',           'w' ]
         self.units['months']  = [ 'monat', 'monate' ]  #the short version would be a capital M,
-                                                       #as I understand it we can't distinguis
+                                                       #as I understand it we can't distinguish
                                                        #between m for minutes and M for months.
         self.units['years']   = [ 'jahr', 'jahre',    'j' ]
 
