@@ -1,11 +1,10 @@
-#!/usr/bin/env python
 
 """
 Test parsing of simple date and times
 """
 
 import unittest, time, datetime
-import parsedatetime.parsedatetime as pt
+import parsedatetime as pdt
 
 
   # a special compare function is used to allow us to ignore the seconds as
@@ -24,9 +23,11 @@ def _compareResults(result, check):
             (t1_min == v1_min) and (t2_yr == v2_yr) and (t2_mth == v2_mth) and (t2_dy == v2_dy) and
             (t2_hr == v2_hr) and (t2_min == v2_min) and (t_flag == v_flag))
 
+
 class test(unittest.TestCase):
+
     def setUp(self):
-        self.cal = pt.Calendar()
+        self.cal = pdt.Calendar()
         self.yr, self.mth, self.dy, self.hr, self.mn, self.sec, self.wd, self.yd, self.isdst = time.localtime()
 
     def testTimes(self):
@@ -53,7 +54,6 @@ class test(unittest.TestCase):
 
         self.assertTrue(_compareResults(self.cal.evalRanges("today 3:30-5PM", start), (targetStart, targetEnd, 2)))
 
-
     def testDates(self):
         start = datetime.datetime(self.yr, self.mth, self.dy, self.hr, self.mn, self.sec).timetuple()
 
