@@ -1,11 +1,10 @@
-#!/usr/bin/env python
 
 """
 Test parsing of simple date and times
 """
 
 import unittest, time, datetime
-import parsedatetime.parsedatetime as pt
+import parsedatetime as pdt
 
 
   # a special compare function is used to allow us to ignore the seconds as
@@ -23,10 +22,9 @@ def _compareResults(result, check):
 
 class test(unittest.TestCase):
     def setUp(self):
-        self.cal = pt.Calendar()
+        self.cal = pdt.Calendar()
         self.yr, self.mth, self.dy, self.hr, self.mn, self.sec, self.wd, self.yd, self.isdst = time.localtime()
 
-
     def testDays(self):
         s = datetime.datetime.now()
         t = s + datetime.timedelta(days=1)
@@ -56,19 +54,24 @@ class test(unittest.TestCase):
 
         self.assertTrue(_compareResults(self.cal.parse(day, start), (target, 1)))
 
-
     def testTimes(self):
         start  = datetime.datetime(self.yr, self.mth, self.dy, self.hr, self.mn, self.sec).timetuple()
         target = datetime.datetime(self.yr, self.mth, self.dy, 23, 0, 0).timetuple()
 
-        self.assertTrue(_compareResults(self.cal.parse('11:00:00 PM', start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('11:00 PM',    start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('11 PM',       start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('11PM',        start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('2300',        start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('23:00',       start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('11p',         start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('11pm',        start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11:00:00 PM',   start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11:00 PM',      start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11 PM',         start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11PM',          start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('2300',          start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('23:00',         start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11p',           start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11pm',          start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11:00:00 P.M.', start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11:00 P.M.',    start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11 P.M.',       start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11P.M.',        start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11p.m.',        start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11 p.m.',       start), (target, 2)))
 
         target = datetime.datetime(self.yr, self.mth, self.dy, 11, 0, 0).timetuple()
 
@@ -80,6 +83,12 @@ class test(unittest.TestCase):
         self.assertTrue(_compareResults(self.cal.parse('11:00',       start), (target, 2)))
         self.assertTrue(_compareResults(self.cal.parse('11a',         start), (target, 2)))
         self.assertTrue(_compareResults(self.cal.parse('11am',        start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11:00:00 A.M.', start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11:00 A.M.',    start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11 A.M.',       start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11A.M.',        start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11a.m.',        start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('11 a.m.',       start), (target, 2)))
 
         target = datetime.datetime(self.yr, self.mth, self.dy, 7, 30, 0).timetuple()
 
@@ -91,7 +100,6 @@ class test(unittest.TestCase):
         self.assertTrue(_compareResults(self.cal.parse('1730',   start), (target, 2)))
         self.assertTrue(_compareResults(self.cal.parse('173000', start), (target, 2)))
 
-
     def testDates(self):
         start  = datetime.datetime(self.yr, self.mth, self.dy, self.hr, self.mn, self.sec).timetuple()
         target = datetime.datetime(2006, 8, 25,  self.hr, self.mn, self.sec).timetuple()
@@ -101,8 +109,10 @@ class test(unittest.TestCase):
         self.assertTrue(_compareResults(self.cal.parse('8/25/06',         start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('August 25, 2006', start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('Aug 25, 2006',    start), (target, 1)))
+        self.assertTrue(_compareResults(self.cal.parse('Aug. 25, 2006',   start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('August 25 2006',  start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('Aug 25 2006',     start), (target, 1)))
+        self.assertTrue(_compareResults(self.cal.parse('Aug. 25 2006',    start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('25 August 2006',  start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('25 Aug 2006',     start), (target, 1)))
 
@@ -116,7 +126,11 @@ class test(unittest.TestCase):
         self.assertTrue(_compareResults(self.cal.parse('08/25',     start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('August 25', start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('Aug 25',    start), (target, 1)))
+        self.assertTrue(_compareResults(self.cal.parse('Aug. 25',   start), (target, 1)))
 
+        # added test to ensure 4-digit year is recognized in the absence of day
+        target = datetime.datetime(2013, 8, 1,  self.hr, self.mn, self.sec).timetuple()
+        self.assertTrue(_compareResults(self.cal.parse('Aug. 2013',   start), (target, 1)))
 
     def testLeapDays(self):
         start  = datetime.datetime(self.yr, self.mth, self.dy, self.hr, self.mn, self.sec).timetuple()
@@ -148,16 +162,16 @@ class test(unittest.TestCase):
             self.assertTrue(self.cal.ptc.daysInMonth(i, 2004), dLeap[i - 1])
             self.assertTrue(self.cal.ptc.daysInMonth(i, 2005), dNormal[i - 1])
 
-
-
     def testDaySuffixes(self):
         start  = datetime.datetime(self.yr, self.mth, self.dy, self.hr, self.mn, self.sec).timetuple()
         target = datetime.datetime(2008, 8, 22,  self.hr, self.mn, self.sec).timetuple()
 
         self.assertTrue(_compareResults(self.cal.parse('August 22nd, 2008', start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('Aug 22nd, 2008',    start), (target, 1)))
+        self.assertTrue(_compareResults(self.cal.parse('Aug. 22nd, 2008',   start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('August 22nd 2008',  start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('Aug 22nd 2008',     start), (target, 1)))
+        self.assertTrue(_compareResults(self.cal.parse('Aug. 22nd 2008',    start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('22nd August 2008',  start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('22nd Aug 2008',     start), (target, 1)))
 
@@ -174,16 +188,19 @@ class test(unittest.TestCase):
 
         self.assertTrue(_compareResults(self.cal.parse('August 23rd, 2008', start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('Aug 23rd, 2008',    start), (target, 1)))
+        self.assertTrue(_compareResults(self.cal.parse('Aug. 23rd, 2008',   start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('August 23rd 2008',  start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('Aug 23rd 2008',     start), (target, 1)))
+        self.assertTrue(_compareResults(self.cal.parse('Aug. 23rd 2008',    start), (target, 1)))
 
         target = datetime.datetime(2008, 8, 25,  self.hr, self.mn, self.sec).timetuple()
 
         self.assertTrue(_compareResults(self.cal.parse('August 25th, 2008', start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('Aug 25th, 2008',    start), (target, 1)))
+        self.assertTrue(_compareResults(self.cal.parse('Aug. 25th, 2008',   start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('August 25th 2008',  start), (target, 1)))
         self.assertTrue(_compareResults(self.cal.parse('Aug 25th 2008',     start), (target, 1)))
-
+        self.assertTrue(_compareResults(self.cal.parse('Aug. 25th 2008',    start), (target, 1)))
 
     def testSpecialTimes(self):
         start  = datetime.datetime(self.yr, self.mth, self.dy, self.hr, self.mn, self.sec).timetuple()
@@ -216,31 +233,55 @@ class test(unittest.TestCase):
         start  = datetime.datetime(self.yr, self.mth, self.dy, self.hr, self.mn, self.sec).timetuple()
         target = datetime.datetime(self.yr, self.mth, self.dy, 0, 0, 0).timetuple()
 
-        self.assertTrue(_compareResults(self.cal.parse('midnight',    start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12:00:00 AM', start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12:00 AM',    start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12 AM',       start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12AM',        start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12am',        start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12a',         start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('0000',        start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('00:00',       start), (target, 2)))
-
+        self.assertTrue(_compareResults(self.cal.parse('midnight',      start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12:00:00 AM',   start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12:00 AM',      start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12 AM',         start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12AM',          start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12am',          start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12a',           start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('0000',          start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('00:00',         start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12:00:00 A.M.', start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12:00 A.M.',    start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12 A.M.',       start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12A.M.',        start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12a.m.',        start), (target, 2)))
 
     def testNoon(self):
         start  = datetime.datetime(self.yr, self.mth, self.dy, self.hr, self.mn, self.sec).timetuple()
         target = datetime.datetime(self.yr, self.mth, self.dy, 12, 0, 0).timetuple()
 
-        self.assertTrue(_compareResults(self.cal.parse('noon',        start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12:00:00 PM', start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12:00 PM',    start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12 PM',       start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12PM',        start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12pm',        start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12p',         start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('1200',        start), (target, 2)))
-        self.assertTrue(_compareResults(self.cal.parse('12:00',       start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('noon',          start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12:00:00 PM',   start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12:00 PM',      start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12 PM',         start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12PM',          start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12pm',          start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12p',           start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('1200',          start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12:00',         start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12:00:00 P.M.', start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12:00 P.M.',    start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12 P.M.',       start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12P.M.',        start), (target, 2)))
+        self.assertTrue(_compareResults(self.cal.parse('12p.m.',        start), (target, 2)))
 
+    # def testMonths(self):
+    #
+    #     start  = datetime.datetime(self.yr, self.mth, self.dy, self.hr, self.mn, self.sec).timetuple()
+    #
+    #     target = datetime.datetime(self.yr, self.mth, self.dy, 12, 0, 0).timetuple()
+    #
+    #     self.assertTrue(_compareResults(self.cal.parse('jun',        start), (target, 2)))
+    #     self.assertTrue(_compareResults(self.cal.parse('12:00:00 PM', start), (target, 2)))
+    #     self.assertTrue(_compareResults(self.cal.parse('12:00 PM',    start), (target, 2)))
+    #     self.assertTrue(_compareResults(self.cal.parse('12 PM',       start), (target, 2)))
+    #     self.assertTrue(_compareResults(self.cal.parse('12PM',        start), (target, 2)))
+    #     self.assertTrue(_compareResults(self.cal.parse('12pm',        start), (target, 2)))
+    #     self.assertTrue(_compareResults(self.cal.parse('12p',         start), (target, 2)))
+    #     self.assertTrue(_compareResults(self.cal.parse('1200',        start), (target, 2)))
+    #     self.assertTrue(_compareResults(self.cal.parse('12:00',       start), (target, 2)))
 
 if __name__ == "__main__":
     unittest.main()
